from dataclasses import dataclass

from soundcloud.resource.base import BaseData


@dataclass(frozen=True)
class OriginalDownload(BaseData):
    """Contains a download link for a track"""

    redirectUri: str



import datetime
from dataclasses import dataclass
from typing import Tuple, Union

from soundcloud.resource.base import BaseData
from soundcloud.resource.message import Message
from soundcloud.resource.user import BasicUser, MissingUser


@dataclass(frozen=True)
class Conversation(BaseData):
    """DM conversation between two users"""

    id: str
    last_message: Message
    read: bool
    started_at: datetime.datetime
    summary: str
    users: Tuple[Union[BasicUser, MissingUser], ...]



import datetime
from dataclasses import dataclass

from soundcloud.resource.base import BaseData
from soundcloud.resource.playlist import AlbumPlaylistNoTracks
from soundcloud.resource.track import BasicTrack


@dataclass(frozen=True)
class BaseLike(BaseData):
    created_at: datetime.datetime
    kind: str


@dataclass(frozen=True)
class TrackLike(BaseLike):
    """Like on a track"""

    track: BasicTrack


@dataclass(frozen=True)
class PlaylistLike(BaseLike):
    """Like on a playlist"""

    playlist: AlbumPlaylistNoTracks
